package server

import (
	"context"
	"github.com/spf13/cast"
	"gomicro-base/api/wallet"
	"gomicro-base/service/wallet/internal/model"
	"gomicro-base/service/wallet/internal/service"
	"google.golang.org/protobuf/types/known/timestamppb"
)

// 检查接口实现
var _ wallet.WalletHandler = &handler{}

// handler类似控制器
type handler struct {
	svc *service.WalletService
}

func (h *handler) GetWallet(ctx context.Context, req *wallet.WalletReq, resp *wallet.WalletResp) error {
	getWallet, err := h.svc.GetWallet(ctx, req)
	if err != nil {
		return err
	}
	*resp = *h.convertUserModel(getWallet)
	return nil
}

func (h *handler) ListWallet(ctx context.Context, req *wallet.ListWalletReq, resp *wallet.ListWalletResp) error {
	if req.Limit <= 0 {
		req.Limit = 15
	}

	listWallet, err := h.svc.ListWallet(ctx, req)
	if err != nil {
		return err
	}

	list := make([]*wallet.WalletResp, 0)
	for _, v := range listWallet {
		c := *h.convertUserModel(v)
		list = append(list, &c)
	}
	resp.List = list
	resp.Limit = req.Limit
	return nil
}

func (h *handler) convertUserModel(users *model.User) (resp *wallet.WalletResp) {
	r := &wallet.WalletResp{
		Id:        cast.ToString(users.Id),
		Username:  users.Username,
		Email:     users.Email,
		Avatar:    users.Avatar,
		Status:    int32(users.Status),
		CreatedAt: timestamppb.New(users.CreatedAt),
		UpdatedAt: timestamppb.New(users.UpdatedAt),
	}
	return r
}
